pub fn train_command(opts: &TrainOptions) -> Result<ServiceCommand>Expand description
Build a command to launch the training binary with common options.
pub fn train_command(opts: &TrainOptions) -> Result<ServiceCommand>Build a command to launch the training binary with common options.